#
# spec file for package ilmbase
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global so_suffix -2_1-11

Name:           ilmbase
Version:        2.1.0
Release:        6.5
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://www.openexr.com
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        http://download.savannah.nongnu.org/releases/openexr/%{name}-%{version}.tar.gz
Source1:        http://download.savannah.nongnu.org/releases/openexr/%{name}-%{version}.tar.gz.sig
Source2:        baselibs.conf
Source3:        ilmbase.keyring
Patch0:         arm-build.diff
Patch1:         fix-i586.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
# Renamed to libilmbase6 to met the Shared Library Policy
Obsoletes:      IlmBase <= 1.0.1
Provides:       IlmBase = %{version}

%description
Base library for Industrial Light & Magic software (OpenEXR).

* Half is a class that encapsulates our 16-bit floating-point
   format.

* IlmThread is a thread abstraction library for use with OpenEXR and
   other software packages.  It currently supports pthreads and
   Windows threads.

* Imath implements 2D and 3D vectors, 3x3 and 4x4 matrices,
   quaternions and other useful 2D and 3D math functions.

* Iex is an exception-handling library.

%package devel
Requires:       libHalf11
Requires:       libIex%{so_suffix}
Requires:       libIexMath%{so_suffix}
Requires:       libIlmThread%{so_suffix}
Requires:       libImath%{so_suffix}
Requires:       libstdc++-devel
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause and GPL-2.0+
Group:          Development/Libraries/C and C++
# Renamed to libilmbase6 to met the Shared Library Policy
Obsoletes:      IlmBase-devel <= 1.0.1
Provides:       IlmBase-devel = %{version}
Obsoletes:      libilmbase-devel <= 1.0.2
Provides:       libilmbase-devel = %{version}

%description devel
Devel files for ilmbase 
Base library for Industrial Light & Magic software (OpenEXR).

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README*
%{_includedir}/OpenEXR
%_libdir/libHalf.so
%_libdir/libIex.so
%_libdir/libImath.so
%_libdir/libIlmThread.so
%_libdir/libIexMath.so
%_libdir/pkgconfig/IlmBase.pc

%package -n libHalf11
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libHalf11
%{summary}.

%post -n libHalf11 -p /sbin/ldconfig

%postun -n libHalf11 -p /sbin/ldconfig

%files -n libHalf11
%defattr(-,root,root,-)
%{_libdir}/libHalf.so.*

%package -n libIexMath%{so_suffix}
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libIexMath%{so_suffix}
%{summary}.

%post -n libIexMath%{so_suffix} -p /sbin/ldconfig

%postun -n libIexMath%{so_suffix} -p /sbin/ldconfig

%files -n libIexMath%{so_suffix}
%defattr(-,root,root,-)
%{_libdir}/libIexMath*.so.*

%package -n libIex%{so_suffix}
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libIex%{so_suffix}
%{summary}.

%post -n libIex%{so_suffix} -p /sbin/ldconfig

%postun -n libIex%{so_suffix} -p /sbin/ldconfig

%files -n libIex%{so_suffix}
%defattr(-,root,root,-)
%{_libdir}/libIex-*.so.*

%package -n libIlmThread%{so_suffix}
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libIlmThread%{so_suffix}
%{summary}.

%post -n libIlmThread%{so_suffix} -p /sbin/ldconfig

%postun -n libIlmThread%{so_suffix} -p /sbin/ldconfig

%files -n libIlmThread%{so_suffix}
%defattr(-,root,root,-)
%{_libdir}/libIlmThread*.so.*

%package -n libImath%{so_suffix}
Summary:        Base library for ILM software (OpenEXR)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libImath%{so_suffix}
%{summary}.

%post -n libImath%{so_suffix} -p /sbin/ldconfig

%postun -n libImath%{so_suffix} -p /sbin/ldconfig

%files -n libImath%{so_suffix}
%defattr(-,root,root,-)
%{_libdir}/libImath*.so.*

%prep
%{?gpg_verify: %gpg_verify %{S:1}}
%setup -q
%patch0
%patch1 -p1

# remove a non unix READMEs
rm README.win32

%build
./bootstrap
export PTHREAD_LIBS="-lpthread"
%configure --disable-static --with-pic
make %{?_smp_mflags}

%install
%{makeinstall}
rm -f %{buildroot}%{_libdir}/*.la

%check
#XXX: workaround for a build fail with gcc45 with -02 on i586
%if 0%{?suse_version} >= 1130
%ifarch %ix86
make CXXFLAGS="`echo "%{optflags}" | sed 's/O2/O1/'`" check
%endif
%endif
make check

%clean
rm -rf %{buildroot}

%changelog
* Thu Aug 21 2014 fcrozat@suse.com
- Add obsoletes to baselibs.conf.
* Wed Nov 27 2013 mvyskocil@suse.com
- update to 2.1.0
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
- small cleanup of spec file
* Mon Jul 15 2013 mvyskocil@suse.com
- update to 2.0.1
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
- add gpg-offline based verification
- use downloads from nongnu.org, instead of github
* Fri Apr 12 2013 mvyskocil@suse.com
- update to 2.0.0
  * Bumped version to track OpenEXR
    (Piotr Stanczyk)
  * Numerous minor fixes, missing includes etc
  * Minor fixes for newer gcc versions and OS X.
    (misc)
  * Preparation for OpenEXR v2 release { remove message for final release }
    (Piotr Stanczyk)
  * Updated the so verison to 10
    (Piotr Stanczyk)
- obsoletes
  * 0001-Correcting-for-incorrect-license-section.patch
  * ilmbase-1.0.3-ucontext-i386.patch
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Sep 27 2012 idonmez@suse.com
- Correct baselibs.conf
* Fri Aug 24 2012 Rene.vanPaassen@gmail.com
- fix build on i586 platforms, by fixing error in declaration of the
  restorControlRegs function
* Wed Aug  8 2012 dmueller@suse.com
- fix build on non-x86 platforms with ucontext
* Tue Aug  7 2012 mvyskocil@suse.cz
- fix bnc#774408 - Proprietary licenses in ilmbase 1.0.3
  * 0001-Correcting-for-incorrect-license-section.patch
* Thu Aug  2 2012 mvyskocil@suse.cz
- update to 1.0.3
  * Updated the so version to 7.
  * Added support for enabling/disabling large stack optimisations, used in
    halfFunction.h.
  * Added ImathNoise.(h/cpp) files. Initializes Perlin noise to match the
    Renderman implmenetation.
  * Added SVD, eigenvalue solver, and procrustes fit calculations
    to ImathMatrixAlgo.
  * Added Imath::FrustumTest for frustum visibility testing.
  * Fixed a stack corruption in the matrix minorOf functions.
- provide a sane packaging conforming to shared library policy
  * source package is ilmbase, ilmbase-devel is the devel package
  * then libFoo$VERSION packages provides so files
* Tue Feb 28 2012 reddwarf@opensuse.org
- Link libIlmThread against lpthread, it was removed in SR#100972
* Sat Feb 18 2012 crrodriguez@opensuse.org
- revert visibility patch, it was not supposed
  to sneak-in yet.. [bnc#747565]
* Sat Jan 21 2012 jengelh@medozas.de
- Remove redundant sections (cf. specfile guidelines)
* Fri Jan 20 2012 crrodriguez@opensuse.org
- Reuse windows code to provide symbol visibility support.
  test suite passes, so unless it is incomplete or buggy
  this should be just fine, if something breaks, open a bug report.
* Mon Jul 26 2010 mvyskocil@suse.cz
- update to 1.0.2 (bug fix release)
- rename to libilmbase6 according Shared Library Policy
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Jun 13 2008 crrodriguez@suse.de
- remove unusable static libraries
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Oct 31 2007 mvyskocil@suse.cz
- inital release (version 1.0.1)
  * need for the update of OpenEXR to 1.6.1
